@@ -15,7 +15,7 @@ from pyage.core.stop_condition import StepLimitStopCondition
 from pyage.solutions.evolution.crossover import SinglePointCrossover
 from pyage.solutions.evolution.evaluation import FloatRastriginEvaluation
 from pyage.solutions.evolution.initializer import float_emas_initializer
-from pyage.solutions.evolution.mutation import UniformFloatMutation
+from pyage.solutions.evolution.mutation import NormalMutation
 
 
 logger = logging.getLogger(__name__)
@@ -38,7 +38,7 @@ transferred_energy = lambda: 40
 
 evaluation = FloatRastriginEvaluation
 crossover = SinglePointCrossover
-mutation = lambda: UniformFloatMutation(probability=1, radius=1)
+mutation = NormalMutation
 
 address_provider = address.SequenceAddressProvider
 
